API docs for “spamfighter.core.counters.ICounter”

# Class s.c.c.ICounter(Interface):

Part of spamfighter.core.counters View Source View In Hierarchy

Счетчик, аккумулирующий информацию по группе одиночных счетчиков `IAtomCounter`.

Счетчик обладает возможностью инкремента и показа текущей информации.

Method | __str__ | Представить текущее состояние счетчика в понятном человеку виде.
Method | increment | Инкрементировать значение счетчика (при этом инкрементируются все одинарные счетчики).

def __str__(): (source)
Представить текущее состояние счетчика в понятном человеку виде.

Returns | (type: `str` )

def increment(value=1): (source)
Инкрементировать значение счетчика (при этом инкрементируются все одинарные счетчики).

Parameters | value | значение инкремента